Generic title

< div / > js < div/ > js

I was born on June 17, 1925, in the progressive city of Berkeley, California. My father was Theodore Stevens Borodin, born in the early 1890's. He was the first son of Stevens Alexander Borodin, who was, with the strange logic of the naming hierarchy of the Russian culture, the first son of Alexander Theodore Borodin. | As I was a first son, I received my great-grandfather's name, and also became Alexander Theodore. And, in keeping with the Russian custom of giving feminine diminutives to all children (as well as to pets and other loved ones regardless of their sex) I answered to the name of Shura Borodin.
< / tbody >

thing